@@ -1,6 +1,6 @@
 // _build.h
 //
-// $Id: _build.h 3727 2008-06-17 15:13:31Z brazilofmux $
+// $Id: _build.h 5798 2016-03-10 02:31:12Z sdennis $
 //
 #ifndef MUX_BUILD_NUM
 extern char szBuildNum[];
@@ -12,8 +12,8 @@ extern char szBuildDate[];
 #define MUX_BUILD_DATE szBuildDate
 #endif // MUX_BUILD_DATE
 
-#define MUX_VERSION       "2.6.5.28"         // Version number
-#define MUX_RELEASE_DATE  "2008-JUN-17"      // Source release date
+#define MUX_VERSION       "2.6.5.34"         // Version number
+#define MUX_RELEASE_DATE  "2016-MAR-09"      // Source release date
     
 // Define if this release is qualified as ALPHA or BETA.
 //
