@@ -1,6 +1,6 @@
 // funmath.cpp -- MUX math function handlers.
 //
-// $Id: funmath.cpp 1862 2007-04-07 17:17:16Z brazilofmux $
+// $Id: funmath.cpp 5776 2016-01-20 15:57:47Z sdennis $
 //
 #include "copyright.h"
 #include "autoconf.h"
@@ -57,7 +57,7 @@ static const char *mux_FPStrings[] = { "+Inf", "-Inf", "Ind", "NaN", "0", "0", "
 #define IEEE_MAKE_TABLESIZE 5
 typedef union
 {
-    INT64  i64;
+    UINT64 i64;
     double d;
 } SpecialFloatUnion;
 
