@@ -1,6 +1,6 @@
 // game.cpp
 //
-// $Id: game.cpp 3050 2007-12-30 06:36:06Z brazilofmux $
+// $Id: game.cpp 4177 2009-02-09 15:53:18Z brazilofmux $
 //
 #include "copyright.h"
 #include "autoconf.h"
@@ -886,7 +886,7 @@ void notify_check(dbref target, dbref sender, const char *msg, int key)
                         continue;
                     }
                     notify_check(recip, sender, buff,
-                             MSG_ME | MSG_F_UP | MSG_F_CONTENTS | MSG_S_INSIDE);
+                         MSG_ME | MSG_F_UP | MSG_F_CONTENTS | MSG_S_INSIDE | (key & (MSG_SAYPOSE | MSG_OOC)));
                 }
             }
             free_lbuf(buff);
@@ -906,7 +906,7 @@ void notify_check(dbref target, dbref sender, const char *msg, int key)
                     buff = add_prefix(obj, target, A_PREFIX, msg,
                         "From a distance,");
                     notify_check(recip, sender, buff,
-                        MSG_ME | MSG_F_UP | MSG_F_CONTENTS | MSG_S_INSIDE);
+                        MSG_ME | MSG_F_UP | MSG_F_CONTENTS | MSG_S_INSIDE | (key & (MSG_SAYPOSE | MSG_OOC)));
                     free_lbuf(buff);
                 }
             }
@@ -945,7 +945,7 @@ void notify_check(dbref target, dbref sender, const char *msg, int key)
                     tbuff = add_prefix(obj, target, A_PREFIX, buff,
                         "From a distance,");
                     notify_check(recip, sender, tbuff,
-                        MSG_ME | MSG_F_UP | MSG_F_CONTENTS | MSG_S_INSIDE);
+                        MSG_ME | MSG_F_UP | MSG_F_CONTENTS | MSG_S_INSIDE | (key & (MSG_SAYPOSE | MSG_OOC)));
                     free_lbuf(tbuff);
                 }
             }
@@ -977,7 +977,7 @@ void notify_check(dbref target, dbref sender, const char *msg, int key)
                 if (obj != target)
                 {
                     notify_check(obj, sender, buff,
-                        MSG_ME | MSG_F_DOWN | MSG_S_OUTSIDE | key & MSG_HTML);
+                        MSG_ME | MSG_F_DOWN | MSG_S_OUTSIDE | (key & (MSG_HTML | MSG_SAYPOSE | MSG_OOC)));
                 }
             }
             if (key & MSG_S_OUTSIDE)
@@ -1010,7 +1010,7 @@ void notify_check(dbref target, dbref sender, const char *msg, int key)
                    && obj != targetloc)
                 {
                     notify_check(obj, sender, buff,
-                    MSG_ME | MSG_F_DOWN | MSG_S_OUTSIDE);
+                        MSG_ME | MSG_F_DOWN | MSG_S_OUTSIDE | (key & (MSG_SAYPOSE | MSG_OOC)));
                 }
             }
             if (key & MSG_S_INSIDE)
@@ -1038,7 +1038,7 @@ void notify_check(dbref target, dbref sender, const char *msg, int key)
                 buff = (char *)msg;
             }
             notify_check(targetloc, sender, buff,
-                MSG_ME | MSG_F_UP | MSG_S_INSIDE);
+                MSG_ME | MSG_F_UP | MSG_S_INSIDE | (key & (MSG_SAYPOSE | MSG_OOC)));
             if (key & MSG_S_INSIDE)
             {
                 free_lbuf(buff);
@@ -2342,10 +2342,22 @@ static void init_sql(void)
 
         if (mush_database)
         {
+#ifdef MYSQL_OPT_RECONNECT
+           // As of MySQL 5.0.3, the default is no longer to reconnect.
+           //
+           my_bool reconnect = 1;
+           mysql_options(m_database, MYSQL_OPT_RECONNECT, (const char *)&reconnect);
+#endif
            if (mysql_real_connect(mush_database,mudconf.sql_server,
                       mudconf.sql_user, mudconf.sql_password,
                       mudconf.sql_database, 0, NULL, 0))
            {
+#ifdef MYSQL_OPT_RECONNECT
+               // Before MySQL 5.0.19, mysql_real_connect sets the option
+               // back to default, so we set it again.
+               //
+               mysql_options(m_database, MYSQL_OPT_RECONNECT, (const char *)&reconnect);
+#endif
                STARTLOG(LOG_STARTUP,"SQL","CONN");
                log_text("Connected to MySQL");
                ENDLOG;
@@ -2400,13 +2412,8 @@ static bool bVersion = false;
 static const char *pErrorBasename = "";
 static bool bServerOption = false;
 
-#ifdef MEMORY_BASED
-#define NUM_CLI_OPTIONS 7
-#else
-#define NUM_CLI_OPTIONS 13
-#endif
-
-static CLI_OptionEntry OptionTable[NUM_CLI_OPTIONS] =
+#define NUM_CLI_OPTIONS (sizeof(OptionTable)/sizeof(OptionTable[0]))
+static CLI_OptionEntry OptionTable[] =
 {
     { "c", CLI_REQUIRED, CLI_DO_CONFIG_FILE },
     { "s", CLI_NONE,     CLI_DO_MINIMAL     },
@@ -2516,15 +2523,15 @@ static void CLI_CallBack(CLI_OptionEntry *p, const char *pValue)
 
 // GenuineIntel
 //
-#define INTEL_MFGSTR0 'uneG'
-#define INTEL_MFGSTR1 'letn'
-#define INTEL_MFGSTR2 'Ieni'
+#define INTEL_MFGSTR_EBX  0x756E6547  // 'uneG'
+#define INTEL_MFGSTR_ECX  0x6C65746E  // 'letn'
+#define INTEL_MFGSTR_EDX  0x49656E69  // 'Ieni'
 
 // AuthenticAMD
 //
-#define AMD_MFGSTR0   'htuA'
-#define AMD_MFGSTR1   'DMAc'
-#define AMD_MFGSTR2   'itne'
+#define AMD_MFGSTR_EBX    0x68747541  // 'htuA'
+#define AMD_MFGSTR_ECX    0x444D4163  // 'DMAc'
+#define AMD_MFGSTR_EDX    0x69746E65  // 'itne'
 
 #define CPUID_1 1
 
@@ -2535,11 +2542,22 @@ static void CLI_CallBack(CLI_OptionEntry *p, const char *pValue)
 #define CPU_EXTMODEL(x)  ((x >> 16) & 0x00000000F)
 #define CPU_EXTFAMILY(x) ((x >> 20) & 0x00000000F)
 
-#define CPU_FEATURE_MMX  0x00800000UL
-#define CPU_FEATURE_FSXR 0x01000000UL
-#define CPU_FEATURE_SSE  0x02000000UL
-#define CPU_FEATURE_SSE2 0x04000000UL
-#define CPU_MSR_SSE3     0x00000001UL
+// Feature bits reported in EDX.
+//
+#define CPU_FEATURE_MMX     0x00800000UL
+#define CPU_FEATURE_FSXR    0x01000000UL
+#define CPU_FEATURE_SSE     0x02000000UL
+#define CPU_FEATURE_SSE2    0x04000000UL
+
+// Feature bits reported in ECX.
+//
+#define CPU_FEATURE2_SSE3   0x00000001UL
+#define CPU_FEATURE2_DTES64 0x00000002UL
+#define CPU_FEATURE2_SSSE3  0x00000200UL
+#define CPU_FEATURE2_SSE41  0x00080000UL
+#define CPU_FEATURE2_SSE42  0x00100000UL
+#define CPU_FEATURE2_POPCNT 0x00800000UL
+#define CPU_FEATURE2_AES    0x02000000UL
 
 // Indicators.
 //
@@ -2560,6 +2578,10 @@ static void CLI_CallBack(CLI_OptionEntry *p, const char *pValue)
 #define CPU_TYPE_FAMILY_6_MMX_FSXR_SSE2      0x00000400UL
 #define CPU_TYPE_FAMILY_6_MMX_FSXR_SSE3      0x00000800UL
 #define CPU_TYPE_FAMILY_F_SSE3               0x00000800UL
+#define CPU_TYPE_FAMILY_6_SSSE3              0x00001000UL
+#define CPU_TYPE_FAMILY_6_SSE41              0x00002000UL
+#define CPU_TYPE_FAMILY_6_SSE42_POPCNT       0x00008000UL
+#define CPU_TYPE_FAMILY_6_AES_DTE64          0x00010000UL
 
 static void cpu_init(void)
 {
@@ -2599,9 +2621,9 @@ static void cpu_init(void)
     }
 
     UINT32 dwHighest;
-    UINT32 dwMfgStr0;
-    UINT32 dwMfgStr1;
-    UINT32 dwMfgStr2;
+    UINT32 dwMfgStr_ebx;
+    UINT32 dwMfgStr_ecx;
+    UINT32 dwMfgStr_edx;
 
     // CPUID is supported.
     //
@@ -2610,9 +2632,9 @@ static void cpu_init(void)
         mov eax,CPUID_0
         cpuid
         mov dwHighest,eax
-        mov dwMfgStr0,ebx
-        mov dwMfgStr1,ecx
-        mov dwMfgStr2,edx
+        mov dwMfgStr_ebx,ebx
+        mov dwMfgStr_ecx,ecx
+        mov dwMfgStr_edx,edx
     }
 
     if (0 == dwHighest)
@@ -2630,15 +2652,15 @@ static void cpu_init(void)
     } CPUMaker;
 
     CPUMaker maker;
-    if (  INTEL_MFGSTR0 == dwMfgStr0
-       && INTEL_MFGSTR1 == dwMfgStr1
-       && INTEL_MFGSTR2 == dwMfgStr2)
+    if (  INTEL_MFGSTR_EBX == dwMfgStr_ebx
+       && INTEL_MFGSTR_ECX == dwMfgStr_ecx
+       && INTEL_MFGSTR_EDX == dwMfgStr_edx)
     {
         maker = Intel;
     }
-    else if (  AMD_MFGSTR0 == dwMfgStr0
-            && AMD_MFGSTR1 == dwMfgStr1
-            && AMD_MFGSTR2 == dwMfgStr2)
+    else if (  AMD_MFGSTR_EBX == dwMfgStr_ebx
+            && AMD_MFGSTR_ECX == dwMfgStr_ecx
+            && AMD_MFGSTR_EDX == dwMfgStr_edx)
     {
         maker = AMD;
     }
@@ -2652,7 +2674,7 @@ static void cpu_init(void)
 
     UINT32 dwSignature;
     UINT32 dwBrand;
-    UINT32 dwMSR;
+    UINT32 dwFeatures2;
     UINT32 dwFeatures;
 
     __asm
@@ -2661,7 +2683,7 @@ static void cpu_init(void)
         cpuid
         mov dwSignature,eax
         mov dwBrand,ebx
-        mov dwMSR,ecx
+        mov dwFeatures2,ecx
         mov dwFeatures,edx
     }
 
@@ -2688,11 +2710,15 @@ static void cpu_init(void)
         dwEffModel = CPU_MODEL(dwSignature);
     }
 
-#define ADVF_MMX  0x00000001UL
-#define ADVF_FSXR 0x00000002UL
-#define ADVF_SSE  0x00000004UL
-#define ADVF_SSE2 0x00000008UL
-#define ADVF_SSE3 0x00000010UL
+#define ADVF_MMX   0x00000001UL
+#define ADVF_FSXR  0x00000002UL
+#define ADVF_SSE   0x00000004UL
+#define ADVF_SSE2  0x00000008UL
+#define ADVF_SSE3  0x00000010UL
+#define ADVF_SSSE3 0x00000020UL
+#define ADVF_SSE41 0x00000040UL
+#define ADVF_SSE42 0x00000080UL
+#define ADVF_AES   0x00000100UL
 
     UINT32 dwAdvFeatures = 0;
 
@@ -2714,11 +2740,26 @@ static void cpu_init(void)
     {
         dwAdvFeatures |= ADVF_SSE2;
     }
-    if (  dwEffFamily <= 5
-       && dwMSR & CPU_MSR_SSE3)
+    if (dwFeatures2 & CPU_FEATURE2_SSE3)
     {
         dwAdvFeatures |= ADVF_SSE3;
     }
+    if (dwFeatures2 & CPU_FEATURE2_SSSE3)
+    {
+        dwAdvFeatures |= ADVF_SSSE3;
+    }
+    if (dwFeatures2 & CPU_FEATURE2_SSE41)
+    {
+        dwAdvFeatures |= ADVF_SSE41;
+    }
+    if (dwFeatures2 & CPU_FEATURE2_SSE42)
+    {
+        dwAdvFeatures |= ADVF_SSE42;
+    }
+    if (dwFeatures2 & CPU_FEATURE2_AES)
+    {
+        dwAdvFeatures |= ADVF_AES;
+    }
 
     // Test whether operating system will allow use of these extensions.
     //
@@ -2736,7 +2777,7 @@ static void cpu_init(void)
         }
         catch (...)
         {
-            dwUseable &= ~(ADVF_MMX|ADVF_SSE|ADVF_SSE2|ADVF_SSE3);
+            dwUseable &= ~(ADVF_MMX|ADVF_SSE|ADVF_SSE2|ADVF_SSE3|ADVF_SSSE3|ADVF_SSE41|ADVF_SSE42|ADVF_AES);
         }
     }
 
@@ -2753,7 +2794,7 @@ static void cpu_init(void)
         }
         catch (...)
         {
-            dwUseable &= ~(ADVF_SSE|ADVF_SSE2|ADVF_SSE3);
+            dwUseable &= ~(ADVF_SSE|ADVF_SSE2|ADVF_SSE3|ADVF_SSSE3|ADVF_SSE41|ADVF_SSE42|ADVF_AES);
         }
     }
 
@@ -2770,7 +2811,7 @@ static void cpu_init(void)
         }
         catch (...)
         {
-            dwUseable &= ~(ADVF_SSE2|ADVF_SSE3);
+            dwUseable &= ~(ADVF_SSE2|ADVF_SSE3|ADVF_SSSE3|ADVF_SSE41|ADVF_SSE42|ADVF_AES);
         }
     }
 
@@ -2787,7 +2828,75 @@ static void cpu_init(void)
         }
         catch (...)
         {
-            dwUseable &= ~(ADVF_SSE3);
+            dwUseable &= ~(ADVF_SSE3|ADVF_SSSE3|ADVF_SSE41|ADVF_SSE42|ADVF_AES);
+        }
+    }
+
+    if (dwUseable & ADVF_SSSE3)
+    {
+        try
+        {
+            __asm
+            {
+                // Let's try a SSSE3 instruction.
+                //
+                phaddw xmm1,xmm2
+            }
+        }
+        catch (...)
+        {
+            dwUseable &= ~(ADVF_SSSE3|ADVF_SSE41|ADVF_SSE42|ADVF_AES);
+        }
+    }
+
+    if (dwUseable & ADVF_SSE41)
+    {
+        try
+        {
+            __asm
+            {
+                // Let's try a SSE41 instruction.
+                //
+                pcmpeqq xmm1,xmm2
+            }
+        }
+        catch (...)
+        {
+            dwUseable &= ~(ADVF_SSE41|ADVF_SSE42|ADVF_AES);
+        }
+    }
+
+    if (dwUseable & ADVF_SSE42)
+    {
+        try
+        {
+            __asm
+            {
+                // Let's try a SSE42 instruction.
+                //
+                pcmpgtq xmm1,xmm2
+            }
+        }
+        catch (...)
+        {
+            dwUseable &= ~(ADVF_SSE42|ADVF_AES);
+        }
+    }
+
+    if (dwUseable & ADVF_AES)
+    {
+        try
+        {
+            __asm
+            {
+                // Let's try a AES instruction.
+                //
+                aesenc xmm1,xmm2
+            }
+        }
+        catch (...)
+        {
+            dwUseable &= ~(ADVF_AES);
         }
     }
 
@@ -2820,7 +2929,32 @@ static void cpu_init(void)
                     {
                         if (dwUseable & ADVF_SSE3)
                         {
-                            if (dwEffFamily < 15)
+                            if (dwUseable & ADVF_SSSE3)
+                            {
+                                if (dwUseable & ADVF_SSE41)
+                                {
+                                    if (dwUseable & ADVF_SSE42)
+                                    {
+                                        if (dwUseable & ADVF_AES)
+                                        {
+                                            __intel_cpu_indicator = CPU_TYPE_FAMILY_6_AES_DTE64;
+                                        }
+                                        else
+                                        {
+                                            __intel_cpu_indicator = CPU_TYPE_FAMILY_6_SSE42_POPCNT;
+                                        }
+                                    }
+                                    else
+                                    {
+                                        __intel_cpu_indicator = CPU_TYPE_FAMILY_6_SSE41;
+                                    }
+                                }
+                                else
+                                {
+                                    __intel_cpu_indicator = CPU_TYPE_FAMILY_6_SSSE3;
+                                }
+                            }
+                            else if (dwEffFamily < 15)
                             {
                                 __intel_cpu_indicator = CPU_TYPE_FAMILY_6_MMX_FSXR_SSE3;
                             }
@@ -2864,7 +2998,7 @@ static void cpu_init(void)
 
     // Report findings to the log.
     //
-    fprintf(stderr, "cpu_init: %s, Family %u, Model %u, %s%s%s%s%s" ENDLINE,
+    fprintf(stderr, "cpu_init: %s, Family %u, Model %u, %s%s%s%s%s%s%s%s%s" ENDLINE,
         (Intel == maker ? "Intel" : (AMD == maker ? "AMD" : "Unknown")),
         dwEffFamily,
         dwEffModel,
@@ -2872,17 +3006,25 @@ static void cpu_init(void)
         (dwUseable & ADVF_FSXR) ? "FSXR ": "",
         (dwUseable & ADVF_SSE)  ? "SSE ": "",
         (dwUseable & ADVF_SSE2) ? "SSE2 ": "",
-        (dwUseable & ADVF_SSE3) ? "SSE3 ": "");
+        (dwUseable & ADVF_SSE3) ? "SSE3 ": "",
+        (dwUseable & ADVF_SSSE3) ? "SSSE3 ": "",
+        (dwUseable & ADVF_SSE41) ? "SSE41 ": "",
+        (dwUseable & ADVF_SSE42) ? "SSE42 ": "",
+        (dwUseable & ADVF_AES) ? "AES ": "");
 
     if (dwUseable != dwAdvFeatures)
     {
         UINT32 dw = dwAdvFeatures & (~dwUseable);
-        fprintf(stderr, "cpu_init: %s%s%s%s%s unsupported by OS." ENDLINE,
+        fprintf(stderr, "cpu_init: %s%s%s%s%s%s%s%s%s unsupported by OS." ENDLINE,
             (dw & ADVF_MMX)  ? "MMX ": "",
             (dw & ADVF_FSXR) ? "FSXR ": "",
             (dw & ADVF_SSE)  ? "SSE ": "",
             (dw & ADVF_SSE2) ? "SSE2 ": "",
-            (dw & ADVF_SSE3) ? "SSE3 ": "");
+            (dw & ADVF_SSE3) ? "SSE3 ": "",
+            (dw & ADVF_SSSE3) ? "SSSE3 ": "",
+            (dw & ADVF_SSE41) ? "SSE41 ": "",
+            (dw & ADVF_SSE42) ? "SSE42 ": "",
+            (dw & ADVF_AES) ? "AES ": "");
     }
 }
 
@@ -2922,8 +3064,7 @@ int DCL_CDECL main(int argc, char *argv[])
 
     // Parse the command line
     //
-    CLI_Process(argc, argv, OptionTable,
-        sizeof(OptionTable)/sizeof(CLI_OptionEntry), CLI_CallBack);
+    CLI_Process(argc, argv, OptionTable, NUM_CLI_OPTIONS, CLI_CallBack);
 
 #ifndef MEMORY_BASED
     if (mudstate.bStandAlone)
