@@ -1,6 +1,6 @@
 // netcommon.cpp
 //
-// $Id: netcommon.cpp 2823 2007-11-28 03:33:36Z brazilofmux $
+// $Id: netcommon.cpp 4623 2010-05-11 16:14:35Z brazilofmux $
 //
 // This file contains routines used by the networking code that do not
 // depend on the implementation of the networking code.  The network-specific
@@ -1819,7 +1819,7 @@ static const char *DumpInfoTable[] =
 
 static void dump_info(DESC *arg_desc)
 {
-    int nDumpInfoTable = 0;
+    size_t nDumpInfoTable = 0;
     while (  nDumpInfoTable < sizeof(DumpInfoTable)/sizeof(DumpInfoTable[0])
           && NULL != DumpInfoTable[nDumpInfoTable])
     {
@@ -1827,7 +1827,7 @@ static void dump_info(DESC *arg_desc)
     }
 
     const char **LocalDumpInfoTable = local_get_info_table();
-    int nLocalDumpInfoTable = 0;
+    size_t nLocalDumpInfoTable = 0;
     while (NULL != LocalDumpInfoTable[nLocalDumpInfoTable])
     {
         nLocalDumpInfoTable++;
@@ -1873,7 +1873,7 @@ static void dump_info(DESC *arg_desc)
         char *buf = alloc_lbuf("dump_info");
         char *bp  = buf;
 
-        int  i;
+        size_t  i;
         bool bFirst = true;
         safe_str("Patches: ", buf, &bp);
         for (i = 0; i < nDumpInfoTable; i++)
