@@ -1,6 +1,6 @@
 // wiz.cpp -- Wizard-only commands.
 //
-// $Id: wiz.cpp 3689 2008-05-31 17:36:05Z brazilofmux $
+// $Id: wiz.cpp 3732 2008-06-22 23:06:23Z brazilofmux $
 //
 
 #include "copyright.h"
@@ -405,17 +405,18 @@ void do_toad
     //
     loc = Location(victim);
     buf = alloc_mbuf("do_toad");
-    const char *pVictimName = Moniker(victim);
+    const char *pVictimMoniker = Moniker(victim);
+    const char *pVictimName = Name(victim);
     mux_sprintf(buf, MBUF_SIZE, "%s has been turned into a slimy toad!",
-        pVictimName);
+        pVictimMoniker);
     notify_except2(loc, executor, victim, executor, buf);
     mux_sprintf(buf, MBUF_SIZE, "You toaded %s! (%d objects @chowned)",
-        pVictimName, count + 1);
+        pVictimMoniker, count + 1);
     notify_quiet(executor, buf);
 
     // Zap the name from the name hash table.
     //
-    mux_sprintf(buf, MBUF_SIZE, "a slimy toad named %s", pVictimName);
+    mux_sprintf(buf, MBUF_SIZE, "a slimy toad named %s", pVictimMoniker);
     delete_player_name(victim, pVictimName);
     s_Name(victim, buf);
     free_mbuf(buf);
